@@ -1,8 +1,8 @@
 --- a/include/autoconf.hin
 +++ b/include/autoconf.hin
-@@ -998,4 +998,8 @@ Added missing headers after gettext upda
+@@ -1003,4 +1003,8 @@ Added missing headers after gettext upda
   */
- #	undef HAVE_LIB_GNUTLS
+ #	undef USE_ZLIB
  
 +/* debian-specific */
 +#define XFACE_ABLE
